STXM Normalization
=======================

STXM Normalization is a PyQt-based graphical user interface. It allows for normalization of images
collected in the TwinMic beamline through Scanning transmission x-ray microscopy (STXM) imaging technique.


----

README
""""""""""""""""" 

**Introduction**
 
To do.

**Installation**

For standard Python installations, install stxmnorm using pip:

.. code:: bash

    pip install -U pip setuptools
    pip install stxmnorm

**Usage**

Once the installation has finished just type on the command line:

.. code:: bash
	
    stxmNorm

**Requirements**

* `Python 2.7 <https://www.python.org/downloads/>`_.
* `Setuptools <https://setuptools.readthedocs.io/en/latest/>`_.
* `Matplotlib <https://matplotlib.org/>`_.
* `NumPy <http://www.numpy.org/>`_.
* `PyQt5 <http://pyqt.sourceforge.net/Docs/PyQt5/installation.html>`_.
* `SIP <https://www.riverbankcomputing.com/software/sip/download>`_.

**To fix**

* 

    
